/*
 * Wire
 * Copyright (C) 2019 Wire Swiss GmbH
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see http://www.gnu.org/licenses/.
 *
 */

import type {APIClient} from '@wireapp/api-client';

class PropertiesService {
  private readonly apiClient: APIClient;

  constructor(apiClient: APIClient) {
    this.apiClient = apiClient;
  }

  /**
   * Clear all properties store for the user.
   * @see https://staging-nginz-https.zinfra.io/swagger-ui/#!/users/clearProperties
   * @returns {Promise} Resolves when all properties for user have been cleared
   */
  deleteProperties(): Promise<void> {
    return this.apiClient.user.api.deleteProperties();
  }

  deletePropertiesByKey(key: string): Promise<void> {
    return this.apiClient.user.api.deleteProperty(key);
  }

  getProperties(): Promise<string[]> {
    return this.apiClient.user.api.getProperties();
  }

  getPropertiesByKey<T = any>(key: string): Promise<T> {
    return this.apiClient.user.api.getProperty<T>(key);
  }

  putPropertiesByKey<T extends Record<string, any>>(key: string, properties: T): Promise<void> {
    return this.apiClient.user.api.putProperty<T>(key, properties);
  }
}

export {PropertiesService};
